@@ -11,7 +11,7 @@ from advisory_parser.exceptions import AdvisoryParserTextException
 from advisory_parser.flaw import Flaw
 from .utils import get_request, get_text_from_url, CVE_REGEX
 
-MARIADB_VULN_PAGE = "https://mariadb.com/kb/en/library/security/"
+MARIADB_VULN_PAGE = "https://mariadb.com/kb/en/security/"
 VERSION_REGEX = re.compile(r"(\d\d?\.\d\.\d\d?)")
 
 
@@ -132,7 +132,15 @@ def parse_mysql_advisory(url):
         description = "\n".join(description)
 
         # Take the text part only, i.e. anything before the CVSS string
-        description, cvss_text = re.split(r"\n\s*CVSS v?3\.[0-9] (?=Base Score)", description)
+        desc_cvss = re.split(r"\n\s*CVSS v?3\.[0-9] (?=Base Score)", description)
+        if len(desc_cvss) != 2:
+            warnings.append(
+                "ERROR: Could not identify CVSS score in {}; skipping:\n\n{}\n---".format(
+                    cve, description
+                )
+            )
+            continue
+        description, cvss_text = desc_cvss
 
         # Filter out some whitespace
         description = description.replace("\n", " ").replace("  ", " ").strip()
